/****************************************************************************
** Meta object code from reading C++ file 'kalgebramobile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalgebra-26.04.3/mobile/kalgebramobile.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kalgebramobile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KAlgebraMobileE_t {};
} // unnamed namespace

template <> constexpr inline auto KAlgebraMobile::qt_create_metaobjectdata<qt_meta_tag_ZN14KAlgebraMobileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAlgebraMobile",
        "variablesChanged",
        "",
        "functionsModel",
        "Analitza::PlotsModel*",
        "variables",
        "QSharedPointer<Analitza::Variables>",
        "examples",
        "Analitza::Dimension",
        "dimension",
        "functionRemoved",
        "QModelIndex",
        "parent",
        "start",
        "end",
        "functionModified",
        "idxA",
        "idxB",
        "functionInserted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'variablesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'functionsModel'
        QtMocHelpers::SlotData<Analitza::PlotsModel *()>(3, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'variables'
        QtMocHelpers::SlotData<QSharedPointer<Analitza::Variables>() const>(5, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'examples'
        QtMocHelpers::SlotData<QStringList(Analitza::Dimension) const>(7, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'functionRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'functionModified'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 16 }, { 0x80000000 | 11, 17 },
        }}),
        // Slot 'functionInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'variables'
        QtMocHelpers::PropertyData<QSharedPointer<Analitza::Variables>>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KAlgebraMobile, qt_meta_tag_ZN14KAlgebraMobileE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAlgebraMobile::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KAlgebraMobileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KAlgebraMobileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KAlgebraMobileE_t>.metaTypes,
    nullptr
} };

void KAlgebraMobile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KAlgebraMobile *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->variablesChanged(); break;
        case 1: { Analitza::PlotsModel* _r = _t->functionsModel();
            if (_a[0]) *reinterpret_cast<Analitza::PlotsModel**>(_a[0]) = std::move(_r); }  break;
        case 2: { QSharedPointer<Analitza::Variables> _r = _t->variables();
            if (_a[0]) *reinterpret_cast<QSharedPointer<Analitza::Variables>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QStringList _r = _t->examples((*reinterpret_cast<std::add_pointer_t<Analitza::Dimension>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->functionRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 5: _t->functionModified((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 6: _t->functionInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KAlgebraMobile::*)()>(_a, &KAlgebraMobile::variablesChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSharedPointer<Analitza::Variables>*>(_v) = _t->variables(); break;
        default: break;
        }
    }
}

const QMetaObject *KAlgebraMobile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAlgebraMobile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KAlgebraMobileE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KAlgebraMobile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KAlgebraMobile::variablesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
